NAME
Weenect::Animal - animal data
(Remember, the tracker is intended for cats and dogs.)
DESCRIPTION
Weenect::Animal describes an animal
METHODS
Supported methods include:
Weenect::Animal - animal data
(Remember, the tracker is intended for cats and dogs.)
Weenect::Animal describes an animal
Supported methods include: